---
applyTo: '*'
---

# Tooling rules

- Prefer Github Actions for automated validation when user commit to the repository
- Don't use Git precommit
- Use ruff and mypy to validate and lint python files
- Use yamllint to validate yaml files
- Use uv to manage the python project and its dependencies